===========
Aggregation
===========

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    Series.arg_max
    Series.arg_min
    Series.implode
    Series.max
    Series.mean
    Series.median
    Series.min
    Series.mode
    Series.nan_max
    Series.nan_min
    Series.product
    Series.quantile
    Series.std
    Series.sum
    Series.var
